@@ -151,20 +151,6 @@ const gchar** documentation_credits = {
 #define HELP_GNOME_DOC_XSLT_DB_OMF_OMF_LANGUAGE "db2omf.omf.language"
 #define HELP_GNOME_DOC_XSLT_DB_OMF_OMF_RELATION "db2omf.omf.relation"
 #define HELP_GNOME_DOC_XSLT_DB_OMF_OMF_RIGHTS "db2omf.omf.rights"
-#define HELP_GNOME_DOC_XSLT_SECTION_RNGDOC "section-rngdoc"
-#define HELP_GNOME_DOC_XSLT_RNGDOC_ID "rngdoc.id"
-#define HELP_GNOME_DOC_XSLT_RNGDOC_TOPLEVEL_ELEMENT "rngdoc.toplevel_element"
-#define HELP_GNOME_DOC_XSLT_SECTION_XSLDOC "section-xsldoc"
-#define HELP_GNOME_DOC_XSLT_XSLDOC_ID "xsldoc.id"
-#define HELP_GNOME_DOC_XSLT_XSLDOC_TOPLEVEL_ELEMENT "xsldoc.toplevel_element"
-#define HELP_GNOME_DOC_XSLT_XSLDOC_CHECKS "xsldoc.checks"
-#define HELP_GNOME_DOC_XSLT_XSLDOC_SUMMARY "xsldoc.summary"
-#define HELP_GNOME_DOC_XSLT_XSLDOC_PARAMS "xsldoc.params"
-#define HELP_GNOME_DOC_XSLT_XSLDOC_NAMED "xsldoc.named"
-#define HELP_GNOME_DOC_XSLT_XSLDOC_INCLUDES "xsldoc.includes"
-#define HELP_GNOME_DOC_XSLT_XSLDOC_REFENTRY_MODE "xsldoc.refentry.mode"
-#define HELP_GNOME_DOC_XSLT_XSLDOC_SUMMARY_MODE "xsldoc.summary.mode"
-#define HELP_GNOME_DOC_XSLT_XSLDOC_DOCBOOK_MODE "xsldoc.docbook.mode"
 #define HELP_GNOME_DOC_XSLT_SECTION_GETTEXT "section-gettext"
 #define HELP_GNOME_DOC_XSLT_GETTEXT_LOCALE "gettext.locale"
 #define HELP_GNOME_DOC_XSLT_GETTEXT_LANGUAGE "gettext.language"
@@ -179,7 +165,6 @@ const gchar** documentation_credits = {
 #define HELP_GNOME_DOC_XSLT_GETTEXT_GET_CHARSET "gettext.get.charset"
 #define HELP_GNOME_DOC_XSLT_SECTION_DB_FORMAT "section-db-format"
 #define HELP_GNOME_DOC_XSLT_FORMAT_CITETITLE "format.citetitle"
-#define HELP_GNOME_DOC_XSLT_FORMAT_DATE "format.date"
 #define HELP_GNOME_DOC_XSLT_FORMAT_QUOTE_OUTER "format.quote.outer"
 #define HELP_GNOME_DOC_XSLT_FORMAT_QUOTE_INNER "format.quote.inner"
 #define HELP_GNOME_DOC_XSLT_FORMAT_APPENDIX_LABEL "format.appendix.label"
@@ -204,6 +189,7 @@ const gchar** documentation_credits = {
 #define HELP_GNOME_DOC_XSLT_TRANSLATING_GETTEXT "translating-gettext"
 #define HELP_GNOME_DOC_XSLT_TRANSLATING_FORMAT_XSL "translating-format2xsl"
 #define HELP_GNOME_DOC_XSLT_TRANSLATING_ROLES "translating-roles"
+#define HELP_GNOME_DOC_XSLT_TRANSLATING_LABELS "translating-labels"
 
 #define HELP_GNOME_DOC_MAKE_INDEX "index"
 #define HELP_GNOME_DOC_MAKE_LEGALNOTICE "legalnotice"
